@@ -80,8 +80,13 @@ class DataFormatter:
                 )
             )
         style_switch = Switch(
-            ["title", "capitalize", "upper", "lower", ""],
-            [str.title, str.capitalize, str.upper, str.lower, True],
+            {
+                "title": str.title,
+                "capitalize": str.capitalize,
+                "upper": str.upper,
+                "lower": str.lower,
+                "": True,
+            },
             use_default_case=True,
             default_case=False,
         )
